

class AwaitableBytes(bytes):
    """A byte-sequence that can be awaited. For sync/async
    cross-compatibility.
    """

    async def _async(self):
        return self

    def __await__(self):
        return self._async().__await__()


# Copyright (C) 2022-2025 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
from ._base import BaseCanonicalException


class DoesNotExist(BaseCanonicalException):
    """This exception may be raised when attempting for perform an operation
    on a resource that does not exist.
    """
    http_status_code: int = 404